{-
 *  Programmer:	Piotr Borek
 *  E-mail:     piotrborek@op.pl
 *  Copyright 2016 Piotr Borek
 *
 *  Distributed under the terms of the GPL (GNU Public License)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-}

module Simple.Locale.Languages (
    LANG (..),
    getSystemLanguage
) where

#ifdef WINDOWS
import System.Win32.NLS
#else
import System.Environment
#endif

import System.IO.Unsafe

data LANG = LANG_UNKNOWN
          | LANG_PL
          deriving Show

#ifdef WINDOWS
detectLanguage :: IO LANG
detectLanguage = do
    let lang = getUserDefaultLCID
    case lang of
        1045 -> return LANG_PL
        _    -> return LANG_UNKNOWN
#else
detectLanguage :: IO LANG
detectLanguage = do
    lang <- getEnv "LANG"
    case lang of
        'p':'l':'_':'P':'L':_ -> return LANG_PL
        _                     -> return LANG_UNKNOWN
#endif

{-# NOINLINE getSystemLanguage #-}
getSystemLanguage :: LANG
getSystemLanguage = unsafePerformIO detectLanguage
